==> bitfront-library-6.0.0.tgz: package/src/app/shared/component/bit-footer.component.ts <==
import {Component,
    Input,
    Output,
    OnInit,
    OnChanges,
    AfterViewInit,
    ViewChild,
    EventEmitter, 
    SimpleChange}   from '@angular/core';
import {Paginator}      from 'primeng/primeng';
import {Observable}     from 'rxjs';

import {PageStatus}     from '../global.constants';
import {BaseFilter}     from '../../base/shared/base.filter';

/** 
* Componenente que muestra un paginador en la sección footer.
**/ 
@Component({   

selector: 'bit-footer',     
template: `
<footer [class]="getStyle()">
    <div>
        <ul *ngIf="typeFooter === 'list'" [hidden]="emptyResult" class="paginas">
            <li><label>&nbsp;&nbsp;&nbsp;&nbsp;Nombre de resultats:</label></li>
            <li class="valor"><span>{{totalItems}}</span></li>
            <li *ngIf="paginator">
                <!-- Hay un bug con pageLinkSize. Pese a recalcularlo bien cuando se selecciona otra ventana de resultados. El componenten no lo actualiza hasta cambiar de página--> 
                <p-paginator #pc [rows]="itemsPerPage" [totalRecords]="totalItems" [pageLinkSize]="pageLinkSize" [rowsPerPageOptions]="[baseItemsPerPage,baseItemsPerPage*2,baseItemsPerPage*5,baseItemsPerPage*10,baseItemsPerPage*20]" (onPageChange)="paginate($event)"></p-paginator>
            </li>
        </ul>
        <ul class="navbar-right">
            <li>                    
                <span class="mensaje mensaje-informacion" *ngIf="searchInitiated"><i class="glyphicon glyphicon-info-sign"></i>{{initMessage}}</span>
                <span class="mensaje mensaje-informacion" *ngIf="searching">{{searchingMessage}}</span>
                <span class="mensaje mensaje-informacion" *ngIf="readOnly">{{readOnlyMessage}}</span>
                <span class="mensaje mensaje-error" *ngIf="!searching && (searchFinished && emptyResult)"><i class="glyphicon glyphicon-alert"></i>{{finishMessage}}</span>
                <span class="mensaje mensaje-error" *ngIf="error"><i class="glyphicon glyphicon-alert"></i>S'ha produït un error</span>
                <bit-help></bit-help>
            </li>
        </ul>
    </div>
</footer>
`
})
export class BitFooterComponent implements OnInit, OnChanges, AfterViewInit {
public static TYPE_LIST: string = 'list';
public static TYPE_FORM: string = 'form';
public static TYPE_BLANK: string = 'blank';

@ViewChild("pc") pc: Paginator;
@Input() autoQueryObs: Observable<BaseFilter>;
@Input() totalItems: number;   // número total de elementos recuperados de la consulta
@Input() paginator: boolean;
@Input() mostrarAvisos: boolean = true;
@Input() fixed: boolean = true; //indicará si lo queremos fijo abajo en la página. Por defecto sí.
pageLinkSize: number; // número de enlaces en el paginador para poder navegar hacia delante o detrás    
itemsPerPage: number = BaseFilter.RESULTADOS_PAGE; // número de elementos por página que mostramos

@Input() status: PageStatus;   // determina en qué estado está la página: PageStatus.Init, PageStatus.SEARCHING, PageStatus.FINISH_SEARCH
@Input("type") typeFooter: string;
@Input() messages: Map<PageStatus, string>;
@Output() onPageChange = new EventEmitter<number>();  //para notificar cambios en la página a mostrar
@Output() onNewPageSize = new EventEmitter<number>(); //para notificar cambios en los elementos a mostrar por página
private baseItemsPerPage: number = BaseFilter.RESULTADOS_PAGE;  // guardamos el número de resultados preconfigurados por página para mostrar la lista de x, x+10 y x+20

ngOnInit(): void{
    if (this.typeFooter == undefined){
        this.typeFooter = "list"
    }
    if (this.paginator == undefined){
        this.paginator = false;
    } //mensajes por defecto si no vienen definidos
    if (this.messages == undefined && this.typeFooter === BitFooterComponent.TYPE_LIST){
        this.messages = new Map<PageStatus, string>();
        this.messages.set(PageStatus.Init, "Introdueixi els criteris de cerca i premi 'Cerca'");
        this.messages.set(PageStatus.Searching, "Cercant...");
        this.messages.set(PageStatus.FinishSearch, "No s'ha trobat cap dada amb les dades introduïdes");
    } else if (this.messages == undefined && this.typeFooter === BitFooterComponent.TYPE_FORM){
        this.messages = new Map<PageStatus, string>();
        this.messages.set(PageStatus.Init, "Premi el botó Desa per actualitzar les dades");
        this.messages.set(PageStatus.Searching, "Enviant la sol·licitud...");
        this.messages.set(PageStatus.FinishSearch, "Dades actualitzades satisfactòriament");
    } else if (this.messages == undefined && this.typeFooter === BitFooterComponent.TYPE_BLANK) {
        console.log('the footer is BLANK!');
        this.messages = new Map<PageStatus, string>();
    }
}

/**
* Cuando tengamos la referncia al componente paginator nos suscribimos al observable para recibir la notificación
* de que se ha realizado una autobúsqueda con una página y/o resultados por página diferente al estándar
*/
ngAfterViewInit(){    
    this.autoQueryObs && this.autoQueryObs.subscribe(filter => {    
        if (this.pc){
            this.itemsPerPage = filter.resultados;    
            this.pc._rows = filter.resultados;
            this.pc._first = (filter.pagina -1) * this.pc._rows;                
            this.pc.updatePageLinks();    
        }    
    });            
}

/**
 * Escucharemos a cambios en las propiedades totalItems para actualizar el paginador con respecto a las páginas que mostramos
 */
ngOnChanges(changes: {[propKey: string]: SimpleChange}) {
    let log: string[] = [];
    for (let propName in changes) {
        let changedProp = changes[propName];
        if (propName === 'totalItems'){
            this.totalItems = changedProp.currentValue;
            (changedProp.previousValue !== changedProp.currentValue)?this.calculatePageLinkSize():undefined; //recalculamos
        }
    }
}

/** Calcula el número de enlaces visibles en el paginador (en el rango entre 1 y 20). */
calculatePageLinkSize() {
   this.pageLinkSize = Math.ceil(this.totalItems / this.itemsPerPage);
   if (this.pageLinkSize <  1) { this.pageLinkSize =  1; }
   if (this.pageLinkSize > 20) { this.pageLinkSize = 20; }
}

/** Establece el número de página en la visualización de resultados. Se invoca cuando el usuario cambia el número de resultados a mostrar o cambia de página */
paginate(event: any): void {
  console.log("Page changed to", event.page);
  if (event.rows !== this.itemsPerPage) {    // han cambiado el número de elementos por página
     //notificamos que los elementos por pagina han cambiado
     this.onNewPageSize.emit(event.rows);
     this.itemsPerPage = event.rows;
     this.calculatePageLinkSize();           // recalculamos el número de enlaces de página
  }
  else {
     //notificamos a nuestro papa que la página ha cambiado 
     this.onPageChange.emit(event.page + 1);
  }
}

getStyle(){
    if (this.fixed){
        return "footer navbar-fixed-bottom";
    }else{
        return "footer"
    }

}

/** Flag: la página está realizando la búsqueda. */
get searchInitiated() { return this.status === PageStatus.Init; }

/** Flag: la página está realizando la búsqueda. */
get searching() { return this.status === PageStatus.Searching; }

/** Flag: la página ha finalizado la última búsqueda. */
get searchFinished() { return this.status === PageStatus.FinishSearch; }

/** Flag: la página está en modo solo lectura */
get readOnly() { return this.status == PageStatus.ReadOnly; }

/** Flag: la página ha finalizado con error */
get error() { return this.status == PageStatus.Error; }

/** Flag: encontrado resultado. */
get foundResult() { return (this.totalItems > 0); }

/** Flag: no hay resultados. */
get emptyResult() { return (this.totalItems === 0); }

get initMessage(): string { return this.messages.get(PageStatus.Init); }

get searchingMessage(): string { return this.messages.get(PageStatus.Searching); }

get finishMessage(): string { return this.messages.get(PageStatus.FinishSearch); }

get readOnlyMessage(): string { return this.messages.get(PageStatus.ReadOnly); }

}

==> bitfront-library-6.6.2.tgz: package/src/app/shared/component/bit-footer.component.ts <==
import {Component,
    Input,
    Output,
    OnInit,
    OnChanges,
    AfterViewInit,
    ViewChild,
    EventEmitter, 
    SimpleChange}   from '@angular/core';
import {Paginator}      from 'primeng/components/paginator/paginator';
import {Observable}     from 'rxjs';

import {PageStatus}     from '../global.constants';
import {BaseFilter}     from '../../base/shared/base.filter';

/** 
* Componenente que muestra un paginador en la sección footer.
**/ 
@Component({   

selector: 'bit-footer',     
template: `
<footer [class]="getStyle()">
    <div>
        <ul *ngIf="typeFooter === 'list'" [hidden]="emptyResult" class="paginas">
            <li><label>&nbsp;&nbsp;&nbsp;&nbsp;Nombre de resultats:</label></li>
            <li class="valor"><span>{{totalItems}}</span></li>
            <li *ngIf="paginator">
                <!-- Hay un bug con pageLinkSize. Pese a recalcularlo bien cuando se selecciona otra ventana de resultados. El componenten no lo actualiza hasta cambiar de página--> 
                <p-paginator #pc [rows]="itemsPerPage" [totalRecords]="totalItems" [pageLinkSize]="pageLinkSize" [rowsPerPageOptions]="[baseItemsPerPage,baseItemsPerPage*2,baseItemsPerPage*5,baseItemsPerPage*10,baseItemsPerPage*20]" (onPageChange)="paginate($event)"></p-paginator>
            </li>
        </ul>
        <ul class="navbar-right">
            <li>                    
                <span class="mensaje mensaje-informacion" *ngIf="searchInitiated"><i class="glyphicon glyphicon-info-sign"></i>{{initMessage}}</span>
                <span class="mensaje mensaje-informacion" *ngIf="searching">{{searchingMessage}}</span>
                <span class="mensaje mensaje-informacion" *ngIf="readOnly">{{readOnlyMessage}}</span>
                <span class="mensaje mensaje-error" *ngIf="!searching && (searchFinished && emptyResult)"><i class="glyphicon glyphicon-alert"></i>{{finishMessage}}</span>
                <span class="mensaje mensaje-error" *ngIf="error"><i class="glyphicon glyphicon-alert"></i>S'ha produït un error</span>
                <bit-help></bit-help>
            </li>
        </ul>
    </div>
</footer>
`
})
export class BitFooterComponent implements OnInit, OnChanges, AfterViewInit {
public static TYPE_LIST: string = 'list';
public static TYPE_FORM: string = 'form';
public static TYPE_BLANK: string = 'blank';

@ViewChild("pc") pc: Paginator;
@Input() autoQueryObs: Observable<BaseFilter>;
@Input() totalItems: number;   // número total de elementos recuperados de la consulta
@Input() paginator: boolean;
@Input() mostrarAvisos: boolean = true;
@Input() fixed: boolean = true; //indicará si lo queremos fijo abajo en la página. Por defecto sí.
pageLinkSize: number; // número de enlaces en el paginador para poder navegar hacia delante o detrás    
itemsPerPage: number = BaseFilter.RESULTADOS_PAGE; // número de elementos por página que mostramos

@Input() status: PageStatus;   // determina en qué estado está la página: PageStatus.Init, PageStatus.SEARCHING, PageStatus.FINISH_SEARCH
@Input("type") typeFooter: string;
@Input() messages: Map<PageStatus, string>;
@Output() onPageChange = new EventEmitter<number>();  //para notificar cambios en la página a mostrar
@Output() onNewPageSize = new EventEmitter<number>(); //para notificar cambios en los elementos a mostrar por página
private baseItemsPerPage: number = BaseFilter.RESULTADOS_PAGE;  // guardamos el número de resultados preconfigurados por página para mostrar la lista de x, x+10 y x+20

ngOnInit(): void{
    if (this.typeFooter == undefined){
        this.typeFooter = "list"
    }
    if (this.paginator == undefined){
        this.paginator = false;
    } //mensajes por defecto si no vienen definidos
    if (this.messages == undefined && this.typeFooter === BitFooterComponent.TYPE_LIST){
        this.messages = new Map<PageStatus, string>();
        this.messages.set(PageStatus.Init, "Introdueixi els criteris de cerca i premi 'Cerca'");
        this.messages.set(PageStatus.Searching, "Cercant...");
        this.messages.set(PageStatus.FinishSearch, "No s'ha trobat cap dada amb les dades introduïdes");
    } else if (this.messages == undefined && this.typeFooter === BitFooterComponent.TYPE_FORM){
        this.messages = new Map<PageStatus, string>();
        this.messages.set(PageStatus.Init, "Premi el botó Desa per actualitzar les dades");
        this.messages.set(PageStatus.Searching, "Enviant la sol·licitud...");
        this.messages.set(PageStatus.FinishSearch, "Dades actualitzades satisfactòriament");
    } else if (this.messages == undefined && this.typeFooter === BitFooterComponent.TYPE_BLANK) {
        console.log('the footer is BLANK!');
        this.messages = new Map<PageStatus, string>();
    }
}

/**
* Cuando tengamos la referncia al componente paginator nos suscribimos al observable para recibir la notificación
* de que se ha realizado una autobúsqueda con una página y/o resultados por página diferente al estándar
*/
ngAfterViewInit(){    
    this.autoQueryObs && this.autoQueryObs.subscribe(filter => {    
        if (this.pc){
            this.itemsPerPage = filter.resultados;    
            this.pc._rows = filter.resultados;
            this.pc._first = (filter.pagina -1) * this.pc._rows;                
            this.pc.updatePageLinks();    
        }    
    });            
}

/**
 * Escucharemos a cambios en las propiedades totalItems para actualizar el paginador con respecto a las páginas que mostramos
 */
ngOnChanges(changes: {[propKey: string]: SimpleChange}) {
    let log: string[] = [];
    for (let propName in changes) {
        let changedProp = changes[propName];
        if (propName === 'totalItems'){
            this.totalItems = changedProp.currentValue;
            (changedProp.previousValue !== changedProp.currentValue)?this.calculatePageLinkSize():undefined; //recalculamos
        }
    }
}

/** Calcula el número de enlaces visibles en el paginador (en el rango entre 1 y 20). */
calculatePageLinkSize() {
   this.pageLinkSize = Math.ceil(this.totalItems / this.itemsPerPage);
   if (this.pageLinkSize <  1) { this.pageLinkSize =  1; }
   if (this.pageLinkSize > 20) { this.pageLinkSize = 20; }
}

/** Establece el número de página en la visualización de resultados. Se invoca cuando el usuario cambia el número de resultados a mostrar o cambia de página */
paginate(event: any): void {
  console.log("Page changed to", event.page);
  if (event.rows !== this.itemsPerPage) {    // han cambiado el número de elementos por página
     //notificamos que los elementos por pagina han cambiado
     this.onNewPageSize.emit(event.rows);
     this.itemsPerPage = event.rows;
     this.calculatePageLinkSize();           // recalculamos el número de enlaces de página
  }
  else {
     //notificamos a nuestro papa que la página ha cambiado 
     this.onPageChange.emit(event.page + 1);
  }
}

getStyle(){
    if (this.fixed){
        return "footer navbar-fixed-bottom";
    }else{
        return "footer"
    }

}

/** Flag: la página está realizando la búsqueda. */
get searchInitiated() { return this.status === PageStatus.Init; }

/** Flag: la página está realizando la búsqueda. */
get searching() { return this.status === PageStatus.Searching; }

/** Flag: la página ha finalizado la última búsqueda. */
get searchFinished() { return this.status === PageStatus.FinishSearch; }

/** Flag: la página está en modo solo lectura */
get readOnly() { return this.status == PageStatus.ReadOnly; }

/** Flag: la página ha finalizado con error */
get error() { return this.status == PageStatus.Error; }

/** Flag: encontrado resultado. */
get foundResult() { return (this.totalItems > 0); }

/** Flag: no hay resultados. */
get emptyResult() { return (this.totalItems === 0); }

get initMessage(): string { return this.messages.get(PageStatus.Init); }

get searchingMessage(): string { return this.messages.get(PageStatus.Searching); }

get finishMessage(): string { return this.messages.get(PageStatus.FinishSearch); }

get readOnlyMessage(): string { return this.messages.get(PageStatus.ReadOnly); }

}
